if [ -z ${CONDA_BUILD+x} ]; then
    source /Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/work/build_env_setup.sh
fi
npm install
npm run build:release
rm -rf node_modules
"${PYTHON}" setup.py install --single-version-externally-managed --record=record.txt
"${PREFIX}/bin/jupyter-nbextension" install nbpresent --py --sys-prefix --overwrite
