.tour-nbpresent {
  .nbp-ui();

  font-size: 18px;
  padding: 0px;
  box-shadow: @z-shadow;
  max-width: 200px;
  min-width: 400px;
  width: 25vw;

  .popover-title {
    font-size: @tour-padding;
    padding: @tour-padding;
  }

  .popover-content {
    padding: @tour-padding;
  }

  .popover-navigation{
    background-color: @ui-bg;
  }

  .popover-navigation .btn {
    color: @jpy-brand;
    font-size: 14px;
    background-color: @ui-bg;
    border: none;

    &:hover{
      color: @ui-bg;
      background-color: @jpy-brand;
    }
  }
}
