export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p"
export ARCH="arm64"
export PREFIX="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p"
export BUILD_PREFIX="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_build_env"
export SYS_PREFIX="/Users/ktietz/demo/mc3"
export SYS_PYTHON="/Users/ktietz/demo/mc3/bin/python"
export SUBDIR="osx-arm64"
export build_platform="osx-arm64"
export SRC_DIR="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/work"
export ROOT="/Users/ktietz/demo/mc3"
export CONDA_PY="38"
export PY3K="1"
export PY_VER="3.8"
export STDLIB_DIR="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib/python3.8"
export SP_DIR="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib/python3.8/site-packages"
export PYTHON="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/bin/python"
export NPY_VER="1.19"
export CONDA_NPY="119"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.34"
export CONDA_PERL="5.34"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="nbpresent"
export PKG_VERSION="3.0.2"
export PKG_BUILDNUM="1"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/Users/ktietz/demo/src/aggregate/nbpresent-feedstock/recipe"
export CPU_COUNT="8"
export LANG="de_DE.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_build_env:/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_build_env/bin:/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p:/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/bin:/Users/ktietz/demo/mc3/bin:/Users/ktietz/demo/mc3/condabin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/share/dotnet:/opt/X11/bin:~/.dotnet/tools:/Library/Frameworks/Mono.framework/Versions/Current/Commands"
export HOME="/Users/ktietz"
export PKG_CONFIG_PATH="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="arm64"
export MACOSX_DEPLOYMENT_TARGET="11.1"
export BUILD="arm64-apple-darwin20.0.0"
export ignore_build_only_deps="{'python', 'numpy'}"
export extend_keys="{'ignore_version', 'extend_keys', 'ignore_build_only_deps', 'pin_run_as_build'}"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('libboost', {'max_pin': 'x.x.x'})])"
export mkl="2021"
export giflib="5"
export dbus="1"
export hdfeos2="2.20"
export libgd="2.2.5"
export hdf4="4.2"
export icu="68"
export proj="7.2.0"
export clang_variant="clang"
export python_impl="cpython"
export r_base="3.5"
export fortran_compiler="gfortran"
export fortran_compiler_version="11.1.0"
export hdf5="1.12.1"
export fontconfig="2.13"
export bzip2="1.0"
export qtwebkit="true"
export lzo="2"
export cxx_compiler_version="12"
export expat="2.4"
export libpng="1.6"
export openssl="1.1.1"
export boost="1.73"
export jpeg="9"
export openjpeg="2.3"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export gmp="6.2"
export blas_impl="openblas"
export cyrus_sasl="2.1.27"
export geos="3.9.1"
export libgdal="3.0"
export VERBOSE_AT="V=1"
export cpu_optimization_target="nocona"
export mpfr="4"
export pixman="0.40"
export apr="1.7.0"
export tk="8.6"
export harfbuzz="2.8"
export proj4="5.2.0"
export libffi="3.3"
export zlib="1.2"
export libprotobuf="3.17.2"
export noarch_python="python"
export libdap4="3.19"
export rust_compiler_version="1.46.0"
export g2clib="1.6"
export freetype="2.10"
export c_compiler="clang"
export r_implementation="r-base"
export libxslt="1.1"
export boost_cpp="1.73"
export r_version="3.5.0"
export openblas="0.3.17"
export cxx_compiler="clangxx"
export VERBOSE_CM="VERBOSE=1"
export channel_targets="defaults"
export rust_compiler="rust"
export libnetcdf="4.8"
export python_implementation="cpython"
export macos_min_version="11.1"
export readline="8.1"
export serf="1.3.9"
export sqlite="3"
export target_platform="osx-arm64"
export cairo="1.16"
export macos_machine="arm64-apple-darwin20.0.0"
export llvm_variant="llvm"
export xz="5"
export libkml="1.3"
export hdfeos5="5.1"
export CONDA_BUILD_SYSROOT="/Library/Developer/CommandLineTools/SDKs/MacOSX11.1.sdk"
export gstreamer="1.14"
export glib="2"
export libtiff="4.2"
export gst_plugins_base="1.14"
export libwebp="1.2.0"
export libgsasl="1.8"
export libxml2="2.9"
export gnu="2.12.2"
export c_compiler_version="12"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/Users/ktietz/demo/mc3/bin/python' -m conda shell.bash hook)"
conda activate "/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_p"
conda activate --stack "/Users/ktietz/demo/mc3/conda-bld/nbpresent_1630565102124/_build_env"
